Module bash_permissions

Module bash_permissions 

Bash permission scanner for hoisted bash. Phase 0 stub; Phase 1 Track C fills in.

Ports OpenCode’s tree-sitter-based permission scan that walks the parsed command tree to identify sub-commands that touch external directories or match permission rules.

Modules

arity
Stable bash permission prefixes.
scan

Structs

PermissionAsk

Enums

PermissionKind

Functions

scan
Scan a bash command and return the list of permission asks needed.