pub fn scan(command: &str, ctx: &AppContext) -> Vec<PermissionAsk>Expand description
Scan a bash command and return the list of permission asks needed.
pub fn scan(command: &str, ctx: &AppContext) -> Vec<PermissionAsk>Scan a bash command and return the list of permission asks needed.