pub struct ImpactResult {
pub symbol: String,
pub file: String,
pub signature: Option<String>,
pub parameters: Vec<String>,
pub total_affected: usize,
pub affected_files: usize,
pub callers: Vec<ImpactCaller>,
pub depth_limited: bool,
pub truncated: usize,
}Expand description
Result of an impact query — enriched callers analysis.
Fields
symbol: StringThe target symbol being analyzed.
file: StringThe target file (relative to project root).
signature: Option<String>Target symbol’s signature, if available.
parameters: Vec<String>Parameter names extracted from the target’s signature.
total_affected: usizeTotal number of affected call sites.
affected_files: usizeNumber of distinct files containing callers.
callers: Vec<ImpactCaller>Enriched caller details.
depth_limited: boolWhether transitive impact expansion stopped at the requested depth.
truncated: usizeNumber of caller edges omitted because of the depth limit.