Module checkpoint

Module checkpoint 

Structs

CheckpointInfo
Metadata about a checkpoint, returned by list/create/restore.
CheckpointStore
Workspace-wide, per-session checkpoint store.

Constants

CHECKPOINT_HYDRATED_NOTICE
User-visible explanation when a checkpoint list was hydrated from disk.
CHECKPOINT_RESTART_NOTICE
User-visible explanation when no durable checkpoints were found after hydration.

Functions

checkpoint_durability
Describe the durable location for a successful checkpoint.