pub struct StatusBarCountValues {
pub errors: Option<usize>,
pub warnings: Option<usize>,
pub dead_code: Option<usize>,
pub unused_exports: Option<usize>,
pub duplicates: Option<usize>,
pub todos: Option<usize>,
pub tier2_stale: bool,
}Expand description
Proven status values. A missing category has not produced a trustworthy value and remains absent instead of being converted to a clean zero.
Fields
errors: Option<usize>warnings: Option<usize>dead_code: Option<usize>unused_exports: Option<usize>duplicates: Option<usize>todos: Option<usize>tier2_stale: boolTrait Implementations
Sourceimpl Clone for StatusBarCountValues
impl Clone for StatusBarCountValues
Sourcefn clone(&self) -> StatusBarCountValues
fn clone(&self) -> StatusBarCountValues
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatusBarCountValues
impl Debug for StatusBarCountValues
Sourceimpl Default for StatusBarCountValues
impl Default for StatusBarCountValues
Sourcefn default() -> StatusBarCountValues
fn default() -> StatusBarCountValues
Returns the “default value” for a type. Read more
impl Eq for StatusBarCountValues
Sourceimpl PartialEq for StatusBarCountValues
impl PartialEq for StatusBarCountValues
impl StructuralPartialEq for StatusBarCountValues