pub fn lookup_github_read_cache_entry(
conn: &Connection,
key: &GithubReadCacheKey,
) -> Result<Option<GithubReadCacheEntry>>Expand description
Look up one cache row using the full resource and authentication-identity key.
pub fn lookup_github_read_cache_entry(
conn: &Connection,
key: &GithubReadCacheKey,
) -> Result<Option<GithubReadCacheEntry>>Look up one cache row using the full resource and authentication-identity key.