pub fn format_validation_errors(errors: &[ValidationError]) -> StringExpand description
Render structured validation errors as a compact line N: message list for
an error message. Used by the refactor handlers when a write was rolled back.
pub fn format_validation_errors(errors: &[ValidationError]) -> StringRender structured validation errors as a compact line N: message list for
an error message. Used by the refactor handlers when a write was rolled back.