Module executor

Module executor 

Structs

BindBlockerSnapshot
Non-blocking scheduler explanation attached to a delayed RouteBind warning.
CompletionHandle
Synchronous completion handle used by the executor tests and the future standalone bridge.
DispatchClassQueueSnapshot
DispatchLivenessSnapshot
DispatchRunningSnapshot
Executor
Concurrent scheduler-dispatch executor.
ExecutorConfig
JobCancellation
Cooperative cancellation for one cancellable executor job.
MutatingLaneSnapshot
SingleFlight
Generation-aware single-flight cache.

Enums

JobCancelOutcome
Outcome of Executor::cancel_job.
JobClass
Scheduler class used to keep deferrable maintenance from occupying the workers reserved for interactive route binds, tool calls, and bash.
Lane
Scheduler lane for command-handler execution.

Functions

current_job_cancellation
The cancellation token of the job running on this worker thread, when the job was submitted through Executor::submit_cancellable_async.

Type Aliases

ExecutorJob