detect_scope_conflicts

Function detect_scope_conflicts 

pub fn detect_scope_conflicts(
    source: &str,
    tree: &Tree,
    insertion_byte: usize,
    _param_names: &[String],
    body_text: &str,
    lang: LangId,
) -> Vec<ScopeConflict>
Detect scope conflicts between the call site scope and the function body being inlined.

Collects all variable declarations at the call site’s scope level (surrounding function body), then checks for collisions with variables declared in body_text.