pub fn detect_missing_tools(
project_root: &Path,
config: &Config,
) -> Vec<MissingTool>Expand description
Detect configured formatters/checkers that are missing for languages present in the project.
pub fn detect_missing_tools(
project_root: &Path,
config: &Config,
) -> Vec<MissingTool>Detect configured formatters/checkers that are missing for languages present in the project.