pub fn apply_selector(
canonical_text: &str,
selector: GithubReadSelector,
) -> StringExpand description
Apply selection to the completed canonical render, never to raw GitHub data.
pub fn apply_selector(
canonical_text: &str,
selector: GithubReadSelector,
) -> StringApply selection to the completed canonical render, never to raw GitHub data.