parse_hashline_patch

Function parse_hashline_patch 

pub fn parse_hashline_patch(patch: &str) -> Result<Patch, HashlineRejection>
Parse a complete patch after raw tool arguments selected the hashline path. Accept an optional *** Begin Patch / *** End Patch envelope, but reject any other preamble or trailing content instead of ignoring it.