pub struct AftWorkspaceDiagnosticParams {
pub identifier: Option<String>,
pub previous_result_ids: Vec<PreviousResultId>,
pub work_done_progress_params: WorkDoneProgressParams,
pub partial_result_params: PartialResultParams,
}Expand description
Parameters for workspace/diagnostic pull requests.
This mirrors lsp_types::WorkspaceDiagnosticParams, but omits absent
optional fields from the JSON payload. The LSP 3.17 schema allows
identifier to be a string or absent, not null.
Fields
identifier: Option<String>The additional identifier provided during registration.
previous_result_ids: Vec<PreviousResultId>The currently known diagnostic reports with their previous result ids.
work_done_progress_params: WorkDoneProgressParamspartial_result_params: PartialResultParamsTrait Implementations
Sourceimpl Clone for AftWorkspaceDiagnosticParams
impl Clone for AftWorkspaceDiagnosticParams
Sourcefn clone(&self) -> AftWorkspaceDiagnosticParams
fn clone(&self) -> AftWorkspaceDiagnosticParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AftWorkspaceDiagnosticParams
impl Debug for AftWorkspaceDiagnosticParams
Sourceimpl<'de> Deserialize<'de> for AftWorkspaceDiagnosticParams
impl<'de> Deserialize<'de> for AftWorkspaceDiagnosticParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AftWorkspaceDiagnosticParams
Sourceimpl PartialEq for AftWorkspaceDiagnosticParams
impl PartialEq for AftWorkspaceDiagnosticParams
Sourcefn eq(&self, other: &AftWorkspaceDiagnosticParams) -> bool
fn eq(&self, other: &AftWorkspaceDiagnosticParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AftWorkspaceDiagnosticParams