pub struct FileParser { /* private fields */ }Expand description
Core parsing engine. Handles language detection, parse tree caching, and query pattern execution via tree-sitter.
Implementations
Sourceimpl FileParser
impl FileParser
Sourcepub fn parse(&mut self, path: &Path) -> Result<(&Tree, LangId), AftError>
pub fn parse(&mut self, path: &Path) -> Result<(&Tree, LangId), AftError>
Parse a file, returning the tree and detected language. Uses cache if the file hasn’t been modified since last parse.
Sourcepub fn parse_cloned(&mut self, path: &Path) -> Result<(Tree, LangId), AftError>
pub fn parse_cloned(&mut self, path: &Path) -> Result<(Tree, LangId), AftError>
Like FileParser::parse but returns an owned Tree clone.
Useful when the caller needs to hold the tree while also calling other mutable methods on this parser.