pub fn parse_patch_header(
lines: &[&str],
start_idx: usize,
) -> Option<PatchHeader>Expand description
Parse a file-operation header line and return its path, optional move destination, and next line index.
pub fn parse_patch_header(
lines: &[&str],
start_idx: usize,
) -> Option<PatchHeader>Parse a file-operation header line and return its path, optional move destination, and next line index.