read_stable

Function read_stable 

pub fn read_stable<T>(
    stat: impl FnMut() -> Result<FileStamp>,
    read: impl FnMut() -> Result<T>,
) -> Result<StableRead<T>, StableReadError>
Performs the stable-read algorithm with injectable stat and read operations.

The plane worker owns this operation because it is the component that will hash the collected bytes next. Watcher dispatch only queues the path.