Bash permission scanner for hoisted bash.
Ports OpenCode’s tree-sitter-based permission scan that walks the parsed command tree to identify sub-commands that touch external directories or match permission rules.
Modules
Structs
Enums
Functions
- scan
- Scan a bash command and return the list of permission asks needed.