Config

Struct Config 

pub struct Config {
Show 16 fields pub project_root: Option<PathBuf>, pub validation_depth: u32, pub checkpoint_ttl_hours: u32, pub max_symbol_depth: u32, pub formatter_timeout_secs: u32, pub type_checker_timeout_secs: u32, pub format_on_edit: bool, pub validate_on_edit: Option<String>, pub formatter: HashMap<String, String>, pub checker: HashMap<String, String>, pub restrict_to_project_root: bool, pub experimental_search_index: bool, pub experimental_semantic_search: bool, pub search_index_max_file_size: u64, pub semantic: SemanticBackendConfig, pub storage_dir: Option<PathBuf>,
}

Fields

project_root: Option<PathBuf>

Root directory of the project being analyzed. None if not scoped.

validation_depth: u32

How many levels of call-graph edges to follow during validation (default: 1).

checkpoint_ttl_hours: u32

Hours before a checkpoint expires and is eligible for cleanup (default: 24).

max_symbol_depth: u32

Maximum depth for recursive symbol resolution (default: 10).

formatter_timeout_secs: u32

Seconds before killing a formatter subprocess (default: 10).

type_checker_timeout_secs: u32

Seconds before killing a type-checker subprocess (default: 30).

format_on_edit: bool

Whether to auto-format files after edits (default: true).

validate_on_edit: Option<String>

Whether to auto-validate files after edits (default: false). When “syntax”, only tree-sitter parse check. When “full”, runs type checker.

formatter: HashMap<String, String>

Per-language formatter overrides. Keys: “typescript”, “python”, “rust”, “go”. Values: “biome”, “prettier”, “deno”, “ruff”, “black”, “rustfmt”, “goimports”, “gofmt”, “none”.

checker: HashMap<String, String>

Per-language type checker overrides. Keys: “typescript”, “python”, “rust”, “go”. Values: “tsc”, “biome”, “pyright”, “ruff”, “cargo”, “go”, “staticcheck”, “none”.

restrict_to_project_root: bool

Whether to restrict file operations to within project_root (default: false). When true, write-capable commands reject paths outside the project root.

experimental_search_index: bool

Enable the experimental trigram search index (default: false).

experimental_semantic_search: bool

Enable the experimental semantic search index (default: false).

search_index_max_file_size: u64

Maximum file size to fully index in bytes (default: 1MB).

semantic: SemanticBackendConfigstorage_dir: Option<PathBuf>

Persistent storage directory for indexes (trigram, semantic). Set by the plugin to the XDG-compliant path (e.g. ~/.local/share/opencode/storage/plugin/aft/). Falls back to ~/.cache/aft/ if not set.

Implementations

Source

impl Config

pub fn semantic_backend_label(&self) -> &'static str