Module executor

Module executor 

Structs

CompletionHandle
Synchronous completion handle used by the executor tests and the future standalone bridge.
DispatchClassQueueSnapshot
DispatchLivenessSnapshot
DispatchRunningSnapshot
Executor
Concurrent scheduler-dispatch executor.
ExecutorConfig
MutatingLaneSnapshot
SingleFlight
Generation-aware single-flight cache.

Enums

JobClass
Scheduler class used to keep deferrable maintenance from occupying the workers reserved for interactive route binds, tool calls, and bash.
Lane
Scheduler lane for command-handler execution.

Type Aliases

ExecutorJob